@@ -1,7 +1,9 @@
 from .engines import mysqlDefault
 from .engines import mysqlDocker
 from .engines import mongoDocker
-
+from .engines import fsDefault
+from .engines import dsDefault
+from .engines import svrDefault
 # Entry Function
 
 
@@ -15,6 +17,12 @@ def start(config):
         MsqModule = mysqlDocker
     elif (DB_ENGINE == 'mongoDocker'):
         MsqModule = mongoDocker
+    elif (DB_ENGINE == 'fsDefault'):
+        MsqModule = fsDefault
+    elif (DB_ENGINE == 'dsDefault'):
+        MsqModule = dsDefault
+    elif (DB_ENGINE == 'svrDefault'):
+        MsqModule = svrDefault        
     else:
         MsqModule = mysqlDefault
 
